.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

Maintainers
----------------------------

Maintainers are responsible for maintaining parts of the code-base. Maintainers have the following responsibilities:

1. Coordinate development activity
2. Make sure code/documentation reviews are being done
3. Coordinate pull-requests
4. Coordinate bug follow-ups
5. Coordinate questions
6. In case of long discussions or arguments, maintainers or others can request a community council decision.

The current maintainers of this project are:

1. Daan van Es
2. Jan Maarten van Doorn
3. Frederik Stoel
4. Bart Pleiter
5. Clara de Smet
6. Egor Dmitriev
7. Lars Schilders

Any community member or Contributor can ask a question or raise an issue to the maintainers by logging a GitHub issue.
